@@ -1,4 +1,5 @@
 import re
+import json
 import logging
 import tempfile
 from pathlib import Path
@@ -319,6 +320,7 @@ class OpenEuler():
                 all_rpm_list.append(rpm_name)
         return all_rpm_list
 
+
     def get_openEuler_all_rpm_list(self, os_version: str, os_arch: str):
         """
         获取指定版本、架构的所有 RPM 包完整名称。s
@@ -345,13 +347,75 @@ class OpenEuler():
                 all_rpm_list.append(rpm_name)
         return all_rpm_list
 
+    def get_openEuler_os_rpm2src(self,os_version,os_arch):
+        rpm2src_file_path=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_os.json"
+        rpm2src_data=dict({})
+        try:
+            with open(rpm2src_file_path, "r",encoding="utf-8") as f:
+                rpm2src_data = json.load(f)
+        except FileNotFoundError:
+            log.error(f"未找到 {rpm2src_file_path} 文件")
+        except json.JSONDecodeError:
+            log.error(f"{rpm2src_file_path} 文件格式错误")
+        except Exception as e:
+            log.error(f"{rpm2src_file_path} 文件读取错误: {str(e)}")
+        finally:
+            return rpm2src_data
 
+    def get_openEuler_update_rpm2src(self,os_version,os_arch):
+        rpm2src_file_path=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_update.json"
+        rpm2src_data=dict({})
+        try:
+            with open(rpm2src_file_path, "r",encoding="utf-8") as f:
+                rpm2src_data = json.load(f)
+        except FileNotFoundError:
+            log.error(f"未找到 {rpm2src_file_path} 文件")
+        except json.JSONDecodeError:
+            log.error(f"{rpm2src_file_path} 文件格式错误")
+        except Exception as e:
+            log.error(f"{rpm2src_file_path} 文件读取错误: {str(e)}")
+        finally:
+            return rpm2src_data
+
+    def get_openEuler_everything_rpm2src(self,os_version,os_arch):
+        rpm2src_file_path=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_everything.json"
+        rpm2src_data=dict({})
+        try:
+            with open(rpm2src_file_path, "r",encoding="utf-8") as f:
+                rpm2src_data = json.load(f)
+        except FileNotFoundError:
+            log.error(f"未找到 {rpm2src_file_path} 文件")
+        except json.JSONDecodeError:
+            log.error(f"{rpm2src_file_path} 文件格式错误")
+        except Exception as e:
+            log.error(f"{rpm2src_file_path} 文件读取错误: {str(e)}")
+        finally:
+            return rpm2src_data
+
+    def get_openEuler_epol_rpm2src(self,os_version,os_arch):
+        rpm2src_file_path=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_epol.json"
+        rpm2src_data=dict({})
+        try:
+            with open(rpm2src_file_path, "r",encoding="utf-8") as f:
+                rpm2src_data = json.load(f)
+        except FileNotFoundError:
+            log.error(f"未找到 {rpm2src_file_path} 文件")
+        except json.JSONDecodeError:
+            log.error(f"{rpm2src_file_path} 文件格式错误")
+        except Exception as e:
+            log.error(f"{rpm2src_file_path} 文件读取错误: {str(e)}")
+        finally:
+            return rpm2src_data
 
 if __name__ == "__main__":
     # 初始化获取器
-    oe = OpenEuler()
-    rs=oe.get_core_src_list()
-    print(rs)
+    # oe = OpenEuler()
+    # rs = oe.get_openEuler_os_rpm2src("24.03-LTS-SP1", "x86_64")
+    # print(len(rs.keys()))
+    # rs = oe.get_openEuler_update_rpm2src("24.03-LTS-SP1", "x86_64")
+    # print(len(rs.keys()))
+    # rs=oe.get_core_src_list()
+    # print(rs)
     # rpm=oe.get_rpm_name_from_full_name("texlive-footbib-doc-svn17115.2.0.7-3.oe2403sp2.noarch.rpm")
     # print(rpm)
     # rpm=oe.get_rpm_name_from_full_name("oeAware-manager-debuginfo-v2.1.1-3.oe2403sp2.x86_64.rpm")
